The changelog format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

This project uses [Semantic Versioning](https://semver.org/) - MAJOR.MINOR.PATCH

# Changelog

## 1.1.0 (2025-01-14)


### Changed

- Updated `kubernetesmod` to work with newer versions of the Kubernetes Python client. [#1](https://github.com/salt-extensions/saltext-kubernetes/issues/1)


## 1.0.1 (2023-12-29)

Initial release of `saltext-kubernetes`. This release tracks the functionality in the core Salt code base at this point.
